@@ -1,5 +1,6 @@
 v <-
 function(x,u, ...){
+    old.contr <- getOption("contrasts")
     # u
     if (!is.factor(u))
        stop("effect modifier must be nominal or ordinal \n")
@@ -11,10 +12,11 @@ function(x,u, ...){
        stop("varying coefficient not well defined. \n")
     options(na.action=na.pass)
     if (is.factor(x) && nlevels(x)==2)
-       x <- -1*model.matrix(~ x, contrasts = list(x="contr.sum"))[,-1]
+       x <- -1*model.matrix(~ x, contrasts = list(x="contr.effect"))[,-1]
     # design
     design <- cbind( int-rowSums(dummies) , dummies) * as.vector(x)
     colnames(design) <- paste(".",levels(u), sep="")
+    options(contrasts = old.contr)
     return(design)
 }
 
